#
# spec file for package python-sunpy
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
# Astropy, SciPy, NumPy require python >= 3.7
%define         skip_python36 1
Name:           python-sunpy
Version:        2.0.7
Release:        1.1
Summary:        SunPy: Python for Solar Physics
License:        BSD-2-Clause AND BSD-3-Clause AND Apache-2.0 AND MIT
URL:            https://github.com/sunpy/sunpy
Source0:        https://files.pythonhosted.org/packages/source/s/sunpy/sunpy-%{version}.tar.gz
Source100:      python-sunpy-rpmlintrc
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module asdf}
BuildRequires:  %{python_module astropy >= 3.2}
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module drms}
BuildRequires:  %{python_module extension-helpers}
BuildRequires:  %{python_module importlib_metadata}
BuildRequires:  %{python_module matplotlib >= 2.2.2}
BuildRequires:  %{python_module numpy-devel > 1.15.0}
BuildRequires:  %{python_module pandas >= 0.23.0}
BuildRequires:  %{python_module parfive >= 1.1.0}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module scikit-image}
BuildRequires:  %{python_module scipy >= 1.0.0}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-aioftp
Requires:       python-astropy >= 3.2
Requires:       python-matplotlib >= 2.2.2
Requires:       python-numpy > 1.15.0
Requires:       python-pandas >= 0.12.0
Requires:       python-scipy > 1.0.0
%if 0%{?python_version_nodots} < 38
Requires:       python-importlib_metadata
%endif
%if 0%{?python_version_nodots} >= 37
Requires:       python-parfive >= 1.1.0
%else
Requires:       python-parfive >= 1.0.2
%endif
# SECTION extras_require:database
Recommends:     python-SQLAlchemy
# /SECTION
# SECTION extras_require:image
Recommends:     python-scikit-image
# /SECTION
# SECTION extras_require:jpeg2000
Recommends:     python-Glymur
# /SECTION
# SECTION extras_require:net
Recommends:     python-beautifulsoup4
Recommends:     python-drms
Recommends:     python-python-dateutil
Recommends:     python-zeep
# /SECTION
# SECTION extras_require:asdf
Recommends:     python-asdf
# /SECTION
# SECTION extras_require:dask[array]
Suggests:       python-dask-array
# /SECTION
# SECTION test requirements
BuildRequires:  %{python_module Glymur}
BuildRequires:  %{python_module aioftp}
BuildRequires:  %{python_module dask-array}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pytest-astropy >= 0.8}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest-mpl}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module zeep}
# /SECTION
%python_subpackages

%description
SunPy is a Python library for solar physics data analysis.

%prep
%autosetup -p1 -n sunpy-%{version}
sed -i -e '/^#!\//, 1d' sunpy/extern/appdirs.py
chmod -x sunpy/data/test/cor1_20090615_000500_s4c1A.fts

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%{python_expand #
find  %{buildroot}%{$python_sitearch} -name '*.h' -delete -print
%fdupes %{buildroot}%{$python_sitearch}
}

%check
mkdir testdir
pushd testdir
%pytest_arch --pyargs sunpy -ra -n auto
popd

%files %{python_files}
%doc README.rst CHANGELOG.rst
%license LICENSE.rst licenses/*
%{python_sitearch}/sunpy
%{python_sitearch}/sunpy-%{version}-py*.egg-info

%changelog
* Sat Jan 23 2021 Benjamin Greiner <code@bnavigator.de>
- Update to 2.0.7
  + Big changlog since 1.1.0.
    See https://docs.sunpy.org/en/stable/whatsnew/2.0.html
    https://github.com/sunpy/sunpy/blob/master/CHANGELOG.rst
    and https://github.com/sunpy/sunpy/releases
  + Highlights from the 2.0 update:
  * sunpy.net.Fido now supports tab completion of search
    attributes. This allows you to do a.Instrument.AIA, and
    print a.Instrument to see the list of known supported
    instruments.
  * sunpy.instr.aia.aiaprep has been deprecated in favor
    of the functionality in the aiapy
    <https://aiapy.readthedocs.io/>__ package.
  * Various fixes and clarifications to pixel indexing in
    the sunpy.map subpackage.
  * Standardization of specifying rectangles in coordinate
    space in the :meth:~sunpy.map.GenericMap.submap and
    :meth:~sunpy.map.GenericMap.draw_rectangle methods of
    ~sunpy.map.GenericMap.
  * HTML quicklook previews of ~sunpy.map.GenericMap and
    ~sunpy.map.MapSequence instances are available with
    the new :meth:~sunpy.map.GenericMap.quicklook and
    :meth:~sunpy.map.MapSequence.quicklook methods,
    respectively. This is also the default display in
    Jupyter <https://jupyter.org/>__ notebooks.
  * Integration of differential rotation into the
    sunpy.coordinates framework. This enables, amongst
    other things, the warping of images with the reproject
    <https://reproject.readthedocs.io/>__ package and the
    plotting of rotated grid lines with :ref:WCSAxes
    <astropy:wcsaxes>.
- Drop fix_importlib_py_ver.patch merged upstream
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove python2 dependencies
- Do not condition importlib_resources, namespace is provided by
  our interpreter to allow compat
* Wed Jan 29 2020 Todd R <toddrme2178@gmail.com>
- Update to version 1.1.0
  + Backwards Incompatible Changes
  * The `sunpy.net.vso.vso.get_online_vso_url` function has been broken into two components, the new `sunpy.net.vso.vso.get_online_vso_url` function takes no arguments (it used to take three) and now only returns an online VSO mirror or None.
    The construction of a `zeep.Client` object is now handled by `sunpy.net.vso.vso.build_client` which has a more flexible API for customising the `zeep.Client` interface.
  * Importing `sunpy.timeseries.timeseriesbase` no longer automatically imports
    Matplotlib.
  * `NOAAIndicesTimeSeries.peek` now checks that the `type` argument is a
    valid string, and raises a `ValueError` if it isn't.
  * Observer-based coordinate frames (`~sunpy.coordinates.frames.Heliocentric` and `~sunpy.coordinates.frames.Helioprojective`) no longer assume a default observer (Earth) if no observer is specified.  These frames can now be used with no observer specified, but most transformations cannot be performed for such frames.  This removal of a default observer only affects `sunpy.coordinates`, and has no impact on the default observer in `sunpy.map`.
  * The callback functions provided to
    `~sunpy.visualization.animator.BaseFuncAnimator` ``button_func`` keyword
    argument now take two positional arguments rather than one. The function
    signature is now ``(animator, event)`` where the first arg is the animator
    object, and the second is the matplotlib mouse event.
  * The colormap stored in SunPy's Map subclasses (ie. ``map.plot_settings['cmap']``)
    can now be colormap string instead of the full `matplotlib.colormap.Colormap`
    object. To get the full `Colormap` object use the new attribute
    ``map.cmap``.
  * Fix a warning in `sunpy.map.GenericMap.rotate` where the truth value of an array
    was being calculated. This changes the behaviour of
    `~sunpy.map.GenericMap.rotate` when the ``angle=`` parameter is not an
    `~astropy.units.Quantity` object to raise `TypeError` rather than `ValueError`.
  + Deprecations and Removals
  * Removed the step of reparing images (replacing non-finite entries with local mean) before coaligning them. The user is expected to do this themselves before coaligning images. If NaNs/non-finite entries are present, a warning is thrown.
    The function `sunpy.image.coalignment.repair_image_nonfinite` is deprecated.
  * The method to convert a `~sunpy.coordinates.frames.Helioprojective` frame from 2D to 3D has been renamed from `~sunpy.coordinates.frames.Helioprojective.calculate_distance` to `~sunpy.coordinates.frames.Helioprojective.make_3d`.  This method is not typically directly called by users.
  * `sunpy.visualization.animator.ImageAnimatorWCS` is now deprecated in favour of
    `~sunpy.visualization.animator.ArrayAnimatorWCS`.
  * ``sunpy.cm`` has been moved to `sunpy.visualization.colormaps` and will be
    removed in a future version.
  + Features
  * Add a new `sunpy.data.manager` and `sunpy.data.cache` for dealing with versioned remote data within functions.
    Please see the `Remote Data Manager <https://docs.sunpy.org/en/latest/dev_guide/remote_data.html>`__ guide.
  * Added the coordinate frames `~sunpy.coordinates.frames.HeliocentricEarthEcliptic` (HEE), `~sunpy.coordinates.frames.GeocentricSolarEcliptic` (GSE), `~sunpy.coordinates.frames.HeliocentricInertial` (HCI), and `~sunpy.coordinates.frames.GeocentricEarthEquatorial` (GEI).
  * Added SunPy Map support for GOES SUVI images.
  * - Support APE14 for ``ImageAnimatorWCS`` in SunPy's visualization module
  * Add ability to disable progressbars when dowloading files using `sunpy.net.helioviewer.py` and edited docstrings to mention this feature.
  * Adds support for searching and downloading SUVI data.
  * Log all VSO XML requests and responses to the SunPy logger at the ``DEBUG``
    level.
  * Transformations between frames in `sunpy.coordinates` can now provide detailed debugging output.  Set the `logging` level to ``DEBUG`` to enable this output.
  * Added the `sunpy.coordinates.sun.carrington_rotation_time` function to
    compute the time of a given Carrington rotation number.
  * A new method has been added to remove columns from a
    `sunpy.timeseries.GenericTimeSeries`.
  * Add `shape` property to TimeSeries.
  * Added ASDF schemas for the new coordinate frames (`~sunpy.coordinates.frames.GeocentricEarthEquatorial`, `~sunpy.coordinates.frames.GeocentricSolarEcliptic`, `~sunpy.coordinates.frames.HeliocentricEarthEcliptic`, `~sunpy.coordinates.frames.HeliocentricInertial`).  See the gallery for an example of using `asdf` to save and load a coordinate frame.
  * `sunpy.visualization.animator.ArrayAnimatorWCS` was added which uses the WCS
    object to get the coordinates of all axes, including the slider labels. It also provides the
    ability to customise the plot by specifying arguments to
    `~astropy.visualization.wcsaxes.WCSAxes` methods and supports animation of
    WCS aware line plots with Astroy 4.0.
  * The returned list of `~sunpy.map.Map` objects is now sorted by filename when
    passing a directory or glob pattern to `~sunpy.map.MapFactory`.
  * Single character wildcards and character ranges can now be passed as
    glob patterns to `~sunpy.map.Map`.
  * `~sunpy.map.Map` now accepts filenames and directories as `pathlib.Path`
    objects.
  * `~sunpy.map.GenericMap` objects now have a ``.cmap`` attribute, which returns the full `~matplotlib.colormap.Colormap`.
    object.
  * `sunpy.io.write_file()` now accepts `~pathlib.Path` objects as filename inputs.
  * `sunpy.map.make_fitswcs_header` now accepts a `tuple` representing the shape of an array as well as the actual array as the ``data`` argument.
  * Made a couple of module imports lazy to reduce the import time of sunpy.map by
    ~40%%.
  * `sunpy.map.GenericMap.wcs` now uses the full FITS header to construct the WCS.
    This adds support for instruments with more complex projections, such as WISPR,
    however does mean that Map will be more sensitive to incorrect or invalid FITS
    headers. If you are using custom headers with SunPy Map you might encounter
    issues relating to this change.
  * `sunpy.visualization.animator.BaseFuncAnimator` now takes an optional
    ``slider_labels`` keyword argument which draws text labels in the center of the
    sliders.
  * Added a more helpful error message when trying to load a file or directory
    that doesn't exist with `Map`.
  * Add ``__repr__`` for `~sunpy.map.MapSequence` objects  so that users can view the
    critical information of all the ``Map`` objects, in a concise manner.
  + Bug Fixes
  * Fixed accuracy issues with the calculations of Carrington longitude (`~sunpy.coordinates.sun.L0`) and Carrington rotation number (`~sunpy.coordinates.sun.carrington_rotation_number`).
  * Updated `sunpy.map.header_helper.make_fitswcs_header` to be more strict on the inputs it accepts.
  * Fix the calculation of ``rsun_ref`` in `~sunpy.map.make_fitswcs_header` and and
    ensure that the default reference pixel is indexed from 1.
  * Fixed the missing transformation between two `~sunpy.coordinates.HeliographicCarrington` frames with different observation times.
  * `sunpy.map.sources.AIAMap` and `sunpy.map.sources.HMIMap` will no longer assume
    the existance of certain header keys.
  * `sunpy.map.make_fitswcs_header` now supports specifying the map projection
    rather than defaulting to ``TAN``.
  * Fix the behaviour of
    `sunpy.coordinates.frames.Helioprojective.calculate_distance` if the
    representation isn't Spherical.
  * Fixed a bug where the longitude of a coordinate would not wrap at the expected angle following a frame transformation.
  * Fixed a bug where passing a time or time interval to the differential rotation function threw an error because the new observer was not in HGS.
  * Fixed bug where `~sunpy.coordinates.ephemeris.get_horizons_coord` was unable to accept `~astropy.time.Time` arrays as input.
  * Fix the ticks on the default heliographic grid overlay so they are not white
    (and normally invisible) by default.
  * Fixed a bug with `sunpy.net.hek.HEKClient` when the results returned were a mixed dataset.
  * Fix `sunpy.physics.differential_rotation.differential_rotate` to rotate in the
    correct direction and to account for the rotation of the heliographic
    coordinate frame with time.
  * Fixed a bug with the handling of changing observation times for transformations between `~astropy.coordinates.HCRS` and `~sunpy.coordinates.frames.HeliographicStonyhurst`, which also indirectly affected other transformations when changing observation times.
  * Fixed all coordinate transformations to properly handle a change in observation time.
  * Fixed the handling of coordinates with velocity information when transforming between Astropy frames and SunPy frames.
  * Fixed `~sunpy.physics.solar_rotation.calculate_solar_rotate_shift` so that it does not calculate a shift between the reference layer and itself, which would sometimes incorrectly result in a shift of a pixel due to numerical precision.
  * Stop crash when ``LineAnimator`` ``axes_ranges`` entry given as ``1D`` array when data is ``>1D``, i.e. as an independent axis.
  * Fixed a `sunpy.coordinates` bug where a frame using the default observer of Earth could have its observer overwritten during a transformation.
  * Fixed a bug where the transformation from `~sunpy.coordinates.frames.Helioprojective` to `~sunpy.coordinates.frames.Heliocentric` used the Sun-observer distance from the wrong frame when shifting the origin, and thus might not give the correct answer if the observer was not the same for the two frames.
  * Fixed a bug with the transformations between `~sunpy.coordinates.frames.Heliocentric` and `~sunpy.coordinates.frames.HeliographicStonyhurst` when the frame observation time was not the same as the observer observation time.  The most common way to encounter this bug was when transforming from `~sunpy.coordinates.frames.Helioprojective` to any non-observer-based frame while also changing the observation time.
  * VSO client `fetch` should not download when `wait` keyword argument is specified.
  * Fixed a bug with `~sunpy.coordinates.wcs_utils.solar_frame_to_wcs_mapping` that assumed that the supplied frame was a SunPy frame.
  * Fixed bugs with `~sunpy.coordinates.wcs_utils.solar_frame_to_wcs_mapping` if the input frame does not include an observation time or an observer.
  * `~sunpy.coordinates.utils.GreatArc` now accounts for the start and end points of the arc having different observers.
  * Fixed situations where 2D coordinates provided to `~sunpy.coordinates.frames.HeliographicStonyhurst` and `~sunpy.coordinates.frames.HeliographicCarrington` were not converted to 3D as intended.  Furthermore, the stored data will always be the post-conversion, 3D version.
  * Fix off by one error in `sunpy.map.make_fitswcs_header` where when using the
    default ``reference_pixel=None`` keyword argument the pixel coordinate of the
    reference pixel was off by +1.
  * Updated both GOES XRS and LYRA dataretriever clients to use `~sunpy.util.scraper.Scraper`, to make sure that files are actually on the servers being queried.
  * Fixing the ordering of lon and lat inputs into make_fitswcs_header
  * Updated the URL for Fermi spacecraft-pointing files to use an HTTPS connection to HEASARC.
  * Fixed a bug where permission denied errors when downloading files are very verbose by adding an error message in `~sunpy.net.fido_factory.UnifiedDownloaderFactory.fetch`.
  * Fixed a malformed call to `astropy.time.Time` in a test, which resulted in an incorrect time scale (UTC instead of TT).
  * Fix incorrect files being included in the tarball, and docs missing from the
    tarball
  * Fixed a bug where clipping behavior had been enabled by default in the plotting normalizers for ``Map`` objects.  Clipping needs to be disabled to make use of the over/under/masked colors in the colormap.
  * Fix a bug with observer based frames that prevented a coordinate with an array of obstimes being transformed to other frames.
  * `sunpy.map.GenericMap` will no longer raise a warning if the posisition of the
    observer is not known for frames that don't need an observer, i.e. heliographic
    frames.
  * Apply `os.path.expanduser` to `sunpy.map.MapFactory` input
    before passing to `glob.glob`
  * Fix multiple instances of `sunpy.map.sources` assuming the type of FITS Header
    values.
  * Fixed a bug with `~sunpy.coordinates.NorthOffsetFrame` where non-spherical representations for the north pole produced an error.
  * Fixed ``map.__repr__`` when the coordinate system information contained in the
    ``CUNIT1/2`` metadata is not set to a known value.
  * Fixed bugs with some coordinate transformations when ``obstime`` is ``None`` on the destination frame but can be assumed to be the same as the ``obstime`` of the source frame.
  * Updated `sunpy.map.mapsequence.MapSequence` so that calling ``_derotate()`` raises ``NotImplementedError``.
    Added associated tests.
  * Fixed pandas plotting registration in `sunpy.timeseries`.
  * Correctly catch and emit a warning when converting a map metadata to a FITS
    header and it contains a keyword with non-ascii characters.
  + Improved Documentation
  * Clean up the docstring for `sunpy.physics.differential_rotation.solar_rotate_coordinate` to make the example clearer.
  * Added new gallery examples and cleaned up various gallery examples.
  * Cleaned and expanded upon the docstrings for each Fido Client.
  * Added clarifying hyperlinks to the gallery example `getting_lasco_observer_location` to link to `astroquery` docs page.
  * Added more details to docstrings in `sunpy.coordinates.frames`.
  * Added a link to package maintainer list in the API Stability page.
  * Improved the contributing guide by updating commands and highlighting text.
  * Removing `.fits` from the end of path kwargs in `sunpy.net.FIDO.fetch` docs to change output file extension from `{file}.fits.fits` to `{file}.fits`.
  * A new example gallery section "Using SunPy with Other Packages" has been added,
    which contains a set of new examples using the `reproject
    <https://reproject.readthedocs.io/>`__ with solar data.
  * Added a table of supported coordinate systems and other miscellaneous improvements to the :ref:`coordinates documentation <sunpy-coordinates>`.
  * Clarified the meaning of :attr:`GenericMap.dsun`.
  * Fixed the plots with multiple subplots in the ``Map`` user guide to properly use `~astropy.visualization.wcsaxes` and to be appropriately sized.
  * Fixed various issues with the gallery example of saving/loading coordinates using `asdf`.
  * Added ``sunpy.__citation__`` with a BibTex entry for citing sunpy.
  * Added an example showing how to display two maps and fade between them.
  * Clarified the meaning of some `GenericMap` observer properties.
  * Added inherited members of `sunpy.map` classes to the docs.
  * Fixed documentation of `sunpy.database.Database.search` by adding ``Returns`` docstring.
  * Updated the docstring for the parameter ``sortby`` in `~sunpy.map.MapSequence` with the default value, valid value and how to disable sorting.
  * Updated the tour guide to reflect that the time series is not random data.
  * Fixes bold type and extra line breaks of remote data manager example
    in `remote_data_manager.py`.
  + Trivial/Internal Changes
  * Allow running our sphinx-gallery examples as Jupyter notebooks via Binder
  * Improve error messages and type checking in
    `sunpy.visualization.animator.image.ImageAnimatorWCS`.
  * Copy the library `distro` into `sunpy/extern`: replaces the deprecated `platform/linux_distribution`
  * The version of Matplotlib used to generate figure tests has been bumped from
    3.0.3 to 3.1.1.
  * Corrected spelling of 'plotting' in timeseries method (changed 'ploting' to 'plotting').
  * Switched to "importlib_metadata" to get package version to speed up import of SunPy.
  * Fix tests for `sunpy.data.data_manager` and ensure they are correctly executed with pytest.
- Add fix_importlib_py_ver.patch
  Fixes a dependency that is not required for later python versions.
  See https://github.com/sunpy/sunpy/pull/3683
* Wed Nov 27 2019 Todd R <toddrme2178@gmail.com>
- Update to version 1.0.6
  + Bug Fixes
  * ~sunpy.coordinates.utils.GreatArc now
    accounts for the start and end points of the arc having different
    observers.
  * Single character wildcards and character ranges can now be passed as
    glob patterns to ~sunpy.map.Map.
  * The returned list of ~sunpy.map.Map
    objects is now sorted by filename when passing a directory or glob
    pattern to ~sunpy.map.MapFactory.
  * Fixed a bug where clipping behavior had been enabled by default in
    the plotting normalizers for Map objects. Clipping needs to be
    disabled to make use of the over/under/masked colors in the
    colormap.
  * Fix a bug with observer based frames that prevented a coordinate
    with an array of obstimes being transformed to other frames.
    sunpy.map.GenericMap will no longer
    raise a warning if the posisition of the observer is not known for
    frames that don't need an observer, i.e. heliographic frames.
  * Apply os.path.expanduser to sunpy.map.MapFactory input before passing
    to glob.glob
  * Fix multiple instances of sunpy.map.sources assuming the type of FITS
    Header values.
  + Improved Documentation
  * Clarified the meaning of GenericMap.dsun.
  * Updated the user guide for Map to use clip_interval.
  * Updated the Venus-transit gallery to use the VSO so that it has
    correct pointing information in the header.
  * Fixed various issues with the gallery example of saving/loading
    coordinates using asdf.
  * Added sunpy.__citation__ with a BibTex entry for citing sunpy.
  * Added an example showing how to display two maps and fade between
    them.
  + Trivial/Internal Changes
  * Copy the library distro into
    `sunpy/extern`: replaces the deprecated platform/linux_distribution
  * Corrected spelling of 'plotting' in timeseries method (changed
    'ploting' to 'plotting').
  + SunPy v1.0.5
  + Bug Fixes
  * Fix incorrect files being included in the tarball, and docs missing
    from the tarball
  + SunPy v1.0.4
  + Bug Fixes
  * Fixed situations where 2D coordinates provided to
    sunpy.coordinates.frames.HeliographicStonyhurst and
    sunpy.coordinates.frames.HeliographicCarrington were not converted to 3D
    as intended. Furthermore, the stored data
    will always be the post-conversion, 3D version.
  * Fix off by one error in sunpy.map.make_fitswcs_header where when
    using the default reference_pixel=None keyword argument the pixel
    coordinate of the reference pixel was off by +1.
  * Fixing the ordering of lon and lat inputs into sunpy.map.make_fitswcs_header
  * Updated the URL for Fermi spacecraft-pointing files to use an HTTPS
    connection to HEASARC.
  + Improved Documentation
  * Improved the contributing guide by updating commands and
    highlighting text.
  * Removing .fits from the end of path
    kwargs in sunpy.net.FIDO.fetch docs
    to change output file extension from {file}.fits.fits to {file}.fits.
- Update to version 1.0.3
  + Features
  * Add ability to disable progressbars when dowloading files using
    sunpy.net.helioviewer.py and edited
    docstrings to mention this feature.
  + Bug Fixes
  * Fixed the handling of coordinates with velocity information when
    transforming between Astropy frames and SunPy frames.
  * Fixed all coordinate transformations to properly handle a change in
    observation time.
  * Fixed
    ~sunpy.physics.solar_rotation.calculate_solar_rotate_shift
    so that it does not calculate a shift between the reference layer
    and itself, which would sometimes incorrectly result in a shift of a
    pixel due to numerical precision.
  * Stop crash when LineAnimator axes_ranges entry given as 1D
    array when data is >1D, i.e. as an independent axis.
  * Fixed a bug where the transformation from
    ~sunpy.coordinates.frames.Helioprojective
    to
    ~sunpy.coordinates.frames.Heliocentric
    used the Sun-observer distance from the wrong frame when shifting
    the origin, and thus might not give the correct answer if the
    observer was not the same for the two frames.
  * Fixed a bug with the transformations between
    ~sunpy.coordinates.frames.Heliocentric
    and
    ~sunpy.coordinates.frames.HeliographicStonyhurst
    when the frame observation time was not the same as the observer
    observation time. The most common way to encounter this bug was when
    transforming from
    ~sunpy.coordinates.frames.Helioprojective
    to any non-observer-based frame while also changing the observation
    time.
  * Fixed a sunpy.coordinates bug where a
    frame using the default observer of Earth could have its observer
    overwritten during a transformation.
  * VSO client fetch should not download
    when wait keyword argument is
    specified.
  * Fixed a bug with
    ~sunpy.coordinates.wcs_utils.solar_frame_to_wcs_mapping
    that assumed that the supplied frame was a SunPy frame.
  * Fixed bugs with
    ~sunpy.coordinates.wcs_utils.solar_frame_to_wcs_mapping
    if the input frame does not include an observation time or an
    observer.
  + Improved Documentation
  * Added more details to docstrings in sunpy.coordinates.frames.
  * Added a link to package maintainer list in the API Stability page.
  + Trivial/Internal Changes
  * Allow running our sphinx-gallery examples as Jupyter notebooks via Binder
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
- Update to Sunpy 1.0.2
  + Backwards Incompatible Changes
  * Move the matplotlib animators from ``sunpy.visualisation.imageanimator`` and
    ``sunpy.visualization.mapcubeanimator`` to `sunpy.visualization.animator`.
  * Make `sunpy.time.parse_time` return `astropy.time.Time` instead of `datetime.datetime`.
  * The properties and methods of `sunpy.time.TimeRange` returns `astropy.time.Time` and `astropy.time.TimeDelta` instead of `datetime.datetime` and `datetime.timedelta` respectively.
  * The `sunpy.instr.goes` module now accepts and returns
    `sunpy.timeseries.XRSTimeSeries` objects only.
  * ``obstime`` keyword param of ``sunpy.instr.goes._goes_lx`` takes a non-scalar `astropy.time.Time` object instead of `numpy.ndarray`. The precision of times contained in `sunpy.timeseries` has been increased to 9 from 6.
  * Removed ``sunpy.net.jsoc.attrs.Time`` because it served the same purpose as `sunpy.net.attrs.Time` after the switch to `astropy.time.Time`.
  * Remove unused ``**kwargs`` within TimeSeries functions.
  * Rotation matrices inside map objects were previously stored as numpy matrices, but are now
    stored as numpy arrays, as numpy will eventually remove their matrix datatype. See
    https://docs.scipy.org/doc/numpy/user/numpy-for-matlab-users.html for more information.
  * The `sunpy.cm.show_colormaps` function now accepts the keyword 'search' instead of 'filter'.
  * The keyword arguments to all client ``.fetch`` methods have been changed to
    support the new parfive downloader and to ensure consisteny across all Fido
    clients.
  * The Helioviewer client has been switched to using the newer Helioviewer API.
    This has meant that we have changed some of the keywords that were passed into client's methods.
    We have enforced that several keywords (observatory,instrument,detector,measurement) need to be defined otherwise the functions cannot return any data.
  * Maps no longer assume that the pixel units are arcseconds if the units aren't
    explicitly set. In addition to this if critical metadata is missing from when
    creating a map, the map will fail to initialize and will raise an error.
  * axis_ranges kwarg of `sunpy.visualization.animator.base.ArrayAnimator`, `sunpy.visualization.animator.image.ImageAnimator` and `sunpy.visualization.animator.line.LineAnimator` now must be entered as None, [min, max] or pixel edges of each array element. Previously, pixel centers were expected.  This change removes ambiguity in interpretation and ensures the extent of the plot can always be accurately derived.
  * All keywords have been added (with defaults) to each `~sunpy.net.helioviewer.HelioviewerClient` function.
    This means that there will be some changes to the style of the PNG screenshot that is returned.
    Returns for the JPEG 2000 and the other functions should be the same but not guaranteed.
  * Changed `sunpy.sun.models.interior` and `sunpy.sun.models.evolution` from `pandas.DataFrame` to `astropy.table.QTable`
  * Minimum numpy version is now >=1.14.5
  * Removed ``sunpy.time.julian_day``, ``sunpy.time.julian_centuries``, ``sunpy.time.day_of_year``, ``sunpy.time.break_time``, ``sunpy.time.get_day``.
  * Updated the solar values in `sunpy.sun.constants` to IAU 2015 values.
  * Renamed `eccentricity_sunearth_orbit` to `eccentricity_sun_earth_orbit`.
  * Renamed ``sunpy.image.rescale`` to `sunpy.image.resample`.
  * Remove the ``basic_plot`` keyword argument from
    `~sunpy.map.Map.GenericMap.peek`. An example has been added to the gallery
    showing how to make a plot like this.
  * `sunpy.map.GenericMap` will no longer use the key `solar_b0` as a value for heliographic latitude.
  * `sunpy.map.GenericMap` now checks for a complete observer location rather than
    individually defaulting coordinates (lat, lon, distance) to Earth position. If
    any one of the three coordinates is missing from the header the observer will
    be defaulted to Earth and a warning raised.
  * `sunpy.sun.sun` functions have been re-implemented using Astropy for significantly improved accuracy.  Some functions have been removed.
  * All of the functions in `sunpy.sun.sun` and all of the Sun-specific functions in `sunpy.coordinates.ephemeris` have been moved to the new module `sunpy.coordinates.sun`.
  + Deprecations and Removals
  * The deprecated ``sunpy.lightcurve``, ``sunpy.wcs`` and ``sunpy.spectra`` modules have now
    been removed.
  * ``sunpy.instr.rhessi.get_obssumm_dbase_file`` ``sunpy.instr.rhessi.get_obssum_filename``, ``sunpy.instr.rhessi.get_obssumm_file`` have been removed. `Fido <sunpy.net.fido_factory.UnifiedDownloader>` should be used to download these files.
  * Removed ``heliographic_solar_center`` in favour of `~sunpy.coordinates.ephemeris.get_sun_L0` and `~sunpy.coordinates.ephemeris.get_sun_B0`
  * Removed ``GenericClient.query`` in favour of `sunpy.net.dataretriever.GenericClient.search`
  * Removed ``sunearth_distance`` in favour of ``get_sunearth_distance``
  * Removed ``remove_lytaf_events_from_lightcurve`` in favour of `sunpy.instr.lyra.remove_lytaf_events_from_timeseries`
  * Removed ``sunpy.cm.get_cmap`` in favour of ``plt.get_cmap``
  * Removed ``database.query`` in favour of `sunpy.database.Database.search`
  * Removed ``sunpy.net.vso.InteractiveVSOClient``
  * Removed ``MapCube`` in favour of `~sunpy.map.MapSequence`
  * Removed ``solar_north`` in favour of ``get_sun_P``
  * Removed ``database.download`` in favour of `sunpy.database.Database.fetch`
  * Removed ``sunpy.map.GenericMap.pixel_to_data`` in favour of `sunpy.map.GenericMap.pixel_to_world`
  * Removed ``GenericClient.get`` in favour of `sunpy.net.dataretriever.GenericClient.fetch`. This changes applies to the other clients as well.
  * Removed `Map.xrange` and `Map.yrange`
  * Removed ``sunpy.net.attrs.Wave`` in favour of `a.Wavelength <~sunpy.net.vso.attrs.Wavelength>`
  * Removed ``JSOCClient.check_request`` in favour of `drms.ExportRequest.status`
  * `sunpy.net.vso.VSOClient.query_legacy` and `sunpy.net.vso.VSOClient.latest` have been deprecated as we strongly recommend people use `sunpy.net.Fido` for all queries.
  * The deprecated ``sunpy.physics.transforms`` module has been removed, it is
    replaced by `sunpy.physics.solar_rotation` and
    `sunpy.physics.differential_rotation`.
  * Removed `~sunpy.sun.sun.solar_cycle_number` because it was fundamentally flawed
  + Features
  * Change arguments to `sunpy.test` from ``offline=`` and ``online=`` to ``online`` and ``online_only``. This matches the behavior of the figure keyword arguments and comes as a part of a move to using a modified version of the Astropy test runner.
  * asdf schemas and tags were added for the SunPy coordinate frames and `~sunpy.map.GenericMap` allowing these objects to be saved to and restored from `asdf <https://asdf.readthedocs.io/>`__ files.
  * The images from image tests are now saved in a local folder for easy access.
  * ``sunpy.map.MapCube`` has been renamed to `sunpy.map.MapSequence` to better reflect its use as a collection of map objects.
  * Net search attributes now support tab completion of values and display a table of possible values when printed, to allow easier discoverability of possible search values.
  * Running the figure tests now creates a page showing the differences between
    the expected figures and the figures produced from running the tests.
  * Add support for Dask arrays in `sunpy.map.Map`. The map factory now checks a whitelist
    of array types rather than strictly checking if the array is of type `numpy.ndarray`.
  * Persist the name of a coordinate, i.e. "earth" even though a concrete
    coordinate object has been calculated and use this string representation to change
    the way the sunpy frames are printed. This is primarily to facilitate displaying
    the name of the body rather than the concrete coordinate when printing a
    `~astropy.coordinates.SkyCoord`.
  * `~sunpy.net.hek.HEKClient.search` now returns an `astropy.table.Table` instead of list of a `dict`.
  * Add a downscaled HMI image to the sample data.
  * Now able to create a `sunpy.map.Map` using an array and a `astropy.wcs.WCS` object.
  * The download manager for `Fido.fetch <sunpy.net.fido_factory.UnifiedDownloader.fetch>` has been replaced with
    `parfive <https://parfive.readthedocs.io/en/latest/>`__. This provides advanced
    progress bars, proper handling of overwriting and the ability to retry failed
    downloads.
  * `sunpy.map.GenericMap` can now save out rice compressed FITS files.
  * Now any SunPyDeprecationWarnings will cause an error when using pytest.
  * Added full Tox support for SunPy tests, documentation build and figure tests.
  * Transition the `sunpy.net.vso.VSOClient` from using suds to `zeep <https://python-zeep.readthedocs.io/en/master/>`__ as the SOAP
    library. This is a more actively maintained library, and should provide better
    support for the VSOs https endpoints. This change should have no effect on the
    public API of the `sunpy.net.vso.VSOClient`.
  * Provided access to the Helioviewer header information using `~sunpy.net.helioviewer.HelioviewerClient.get_jp2_header` function.
  * Add a new WSDL URL and port to support SunPy use of VSO instance at SDAC.
  * Add support for COSMO K-Coronograph (KCOR) FITS data.
  * Add logger messaging system based on `~astropy.logger.AstropyLogger`, cleaned up all warnings, removed all print statements.
  * The function `sunpy.image.coalignment.get_correlation_shifts` now issues an error when the number of dimensions
    are not correct instead of a warning and returning None.
  * The default location of the sunpy sample data has changed to be in the platform
    specific data directory as provided by `appdirs <https://github.com/ActiveState/appdirs>`__.
  * Add timeseries support for EVE/ESP level 1 data in `sunpy.timeseries.sources.eve`
  * The default style for Map plots have changed to reflect the changes in Astropy
    3.2.
  * `sunpy.coordinates.ephemeris.get_body_heliographic_stonyhurst` can now account for light travel time when computing the (apparent) body position, as long as the observer location is provided.
  * Added a helper function (`sunpy.map.make_fitswcs_header`) that allows users to create a meta header for custom created `sunpy.map.GenericMap`.
  * Map plotting now accepts the optional keyword `clip_interval` for specifying a percentile interval for clipping.  For example, if the interval (5%%, 99%%) is specified, the bounds of the z axis are chosen such that the lowest 5%% of pixels and the highest 1%% of pixels are excluded.
  * The new function `~sunpy.coordinates.get_horizons_coord` enables querying JPL HORIZONS for the locations of a wide range of solar-system bodies, including spacecraft.
  + Bug Fixes
  * Fix the bug that prevented VSO queries for HMI data from downloading file
    without specifying ``a.Physobs``.
  * Fix `sunpy.map.mapcube.MapCube.plot`. The code had not been updated to support the changes to the wcsaxes helper functions.
  * Replace all use of the deprecated ``sunpy.cm.get_cmap`` with `matplotlib.pyplot.get_cmap` to prevent deprecation warnings being raised.
  * Fix generation of the coordinate transformation graph with Astropy 3.1.dev
  * Prevent helioviewer from erroring when downloading file to a directory that
    does not exist. It will now create the directory when required.
  * Fix transformations into/out of Heliographic Stonyhurst frame when
    the coordinate representation is Cartesian.
  * Running the figure tests with ``setup.py test`` now saves the figures and the hashes to the same directory as setup.py.
  * `sunpy.instr.fermi.met_to_utc` now returns the correct utc time which takes into account the leap seconds that have passed.
  * Support passing Python file objects to `sunpy.io.fits.write`.
  * Added DRMS to setup.py so sunpy[all] installs it as a dependancy.
  * Fix eve 0cs timeseries seperator regex to support Python 3.7
  * Fix the bug which crashes `~sunpy.map.sources.LASCOMap` for when 'date-obs' is reformatted agian from a self applied function.
  * Change all instances of quantity_allclose to `astropy.units.allclose` this prevents pytest being needed to import `sunpy.coordinates` on Astropy 3
  * Fix RHESSI obssum file downloading to include the final day in the time range.
  * Raise an error when transforming between HPC and HCC frames if the observer is not the same.
  * Replaces the existing LASCO C2 and C3 color maps with new ones that perform better with JP2 and Level 0.5, 1 data.
  * Do not attempt to save a FITS header comment for a keyword which is not in the header. This prevents an error on saving some maps after the metadata had been modified but not the comments.
  * Add support for `~sunpy.map.sources.HMIMap` objects as input to `sunpy.instr.aia.aiaprep`.
  * User can convert between HPC and HCC coordinates with different observers. This is implemented by automatically transforming the coordinate into HGS and then changing observer, and then transforming back to HCC.
  * Changed default file type for Helioviewer to prevent decode errors.
  * Increase figure size to avoid cutting off longer colormap names in `sunpy.cm.show_colormaps`.
  * The sample data directory will no longer be created until files are downloaded
    to it.
  * Timeseries and lightcurve will now respect updated config values for download directory.
  * Always use _default_wrap_angle rather than hard coding a wrap angle in the init
    of a sunpy coordinate frame
  * Ensure imageanimators only slice arrays with integers
  * Fixed `sunpy.io.fits.write` to handle the keyword ``COMMENT`` correctly.
  * If Carrington longitude ("crln_obs") is found in the FITS header, `~sunpy.map.Map` converts this to the correct Heliographic longitude.
  * `sunpy.net.helio.hec.HECClient.time_query` now resolves the correct input time format.
  * Fixes the calculation of the solar rotation of coordinates and the differential rotation of `sunpy.map.GenericMap`.
  * Added back the FERMI GBM client to `sunpy.net.dataretriever.sources`.
  * Fix bug in `sunpy.net.hek` which raised and error if a search returned zero results, now returns an empty `sunpy.net.hek.HEKTable`.
  * `~sunpy.map.sources.AIAMap` now uses the provided HAE coordinates instead of the provided HGS coordinates to determine the observer location.
  * Correctly zero pad milliseconds in the `sunpy.util.scraper.Scraper` formatting to prevent errors when the millisecond value was less than 100.
  * Fix `sunpy.util.scraper.Scraper` failing if a directory is not found on a remote server.
  * Correctly extract observer location from MDI and EIT data
  * Fix HGS <> HCRS test due to Ecliptic frame changes in astropy 3.2
  * Fixes bug when creating a timeseries from a URL and bug when creating a TimeSeries from  older GOES/XRS fits files.
  * Added `~sunpy.map.EUVIMap.rsun_obs`. It returns a quantity in arcsec consistent with other `sunpy.map.GenericMap` and overwrites mapbase's assumption of a photospheric limb as seen from Earth.
  * Fixed bugs related to using `~sunpy.map.GenericMap.plot` and `~sunpy.map.GenericMap.peek` with the ``inline`` Matplotlib backend in Jupyter notebook.
  * Make a correction to `sunpy.coordinates.wcs_utils.solar_wcs_frame_mapping` so
    that `astropy.wcs.WCS` objects are correctly converted to
    `sunpy.coordinates.frames` objects irrespective of the ordering of the axes.
  * The `solar_rotate_coordinate` function returns a coordinate that accounts for the location of the new observer.
  * Add support for rotation parameters to `sunpy.map.make_fitswcs_header`.
  * Improve the implementation of `~sunpy.physics.differential_rotation.differential_rotate` the image warping when transforming Maps for differential rotation and change in observer position.
  * Fix a bug where new helioviewer sources potentially cause `~sunpy.net.helioviewer.HelioviewerClient.data_sources` to error.
  + Improved Documentation
  * Organise the gallery into sections based on example type and tidy up a little.
  * Added gallery example showing the conversion of Helioprojective Coordinates to Altitude/Azimuth Coordinates to and back.
  * Add contribution guidelines for the sunpy example gallery.
  * Added a gallery example for "Downloading and plotting a HMI image" and "Creating a Composite map".
  * Added an example for `~sunpy.visualization.animator.ImageAnimatorWCS`.
  * Minor changes to the developer guide regarding sprint labels.
  * Copyedited and corrected the solar cycles example.
  * Changed "online" mark to "remote_data" and made formatting of marks consistent.
  * Add a missing plot to the end of the units and coordinates guide.
  * Added gallery example showing how to access the SunPy colormaps
  * Added gallery example showing how to access the SunPy solar physics constants.
  * Major clean up of the developer documentation.
  * Overhaul of the install intructions for the guide section of our documentation.
  + Trivial/Internal Changes
  * `~sunpy.time.parse_time` now uses `singledispatch` underneath.
  * Revert the handling of ``quantity_allclose`` now that `astropy/astropy#7252 <https://github.com/astropy/astropy/pull/7252>`__ is merged. This also bumps the minimum astropy version to 3.0.2.
  * Replace the subclasses of matplotlib Slider and Button in `sunpy.visualization` with partial functions.
  * Sort the ana C source files before building to enable reproducible builds.
  * We are now using `towncrier <https://github.com/hawkowl/towncrier>`__ to
    generate our changelogs.
  * Moved figure tests to Python 3.6.
  * Removed old metaclass used for Map and TimeSeries as we have now moved to Python 3.6.
  * Updated astropy_helpers to v3.0.2.
  * When running image tests, a comparison HTML page is now generated to show
    the generated images and expected images.
  * Change to using pytest-cov for coverage report generation to enable support for parallel builds
  * Use of `textwrap` to keep source code indented when multiline texts is used
  * Fix mispelling of private attribute ``_default_heliographic_latitude`` in map.
  * Miscellaneous fixes to developer docs about building sunpy's documentation.
  * Changed `sunpy.instr.aia.aiaprep` to update BITPIX keyword to reflect the float64 dtype.
  * Remove warning from ``GenericMap.submap`` when using pixel ``Quantities`` as input.
  * Remove the usage of six and all ``__future__`` imports
  * Fix SunPy Coordinate tests with Astropy 3.1
  * Stores entries from directories into database sorted by name. It adds mocks to the database user guide examples.
  * Fix all DeprecationWarning: invalid escape sequence.
  * Used `unittest.mock` for creating offline tests for simulating online tests for `test_noaa.py`
  * Fix support for pip 19 and isolated builds
  * Moved to using `AppDirs <https://github.com/ActiveState/appdirs>`__ as the place to host our configuration file.
  * Users can now use fewer keywords in our `~sunpy.net.HelioviewerClient` to access the available sources. Either by `observatory` and `measurement` or `instrument` and `measurement` as this much information is enough to get the source ID for most of the cases.
  * Remove the pytest dependancy on the ``GenericMap`` asdf tag.
  * Fix initialization of `~sunpy.net.vso.VSOClient` when no WSDL link is found.
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Update to version 0.9.5
  + New Features
  * Added TimeUTime class to support utime. [#2409]
  * Example for fine-grained use of ticks and grids [#2435]
  * Maintiners Workflow Guide [#2411]
  * Decorator to append and/or prepend doc strings [#2386]
  * Adding `python setup.py test --figure-only` [#2557]
  * Fido.fetch now accepts pathlib.Path objects for path attribute.[#2559]
  * The `~sunpy.coordinates.HeliographicStonyhurst` coordinate system can now be specified
    using a cartesian system, which is sometimes known as the
    "Heliocentric Earth equatorial" (HEEQ) coordinate system. [#2437]
  + API Changes
  * `sunpy.coordinates.representation` has been removed. Longitude wrapping is now done in the constructor of the frames. [#2431]
  * Propagation of ``obstime`` in the coordinate frame transformation has changed, this means in general when transforming directly between frames (not `~astropy.coordinates.SkyCoord`) you will have to specify ``obstime`` in more places. [#2461]
  * Transforming between Heliographic Stonyhurst and Carrington now requires that ``obstime`` be defined and the same on both the input and output frames. [#2461]
  * Removed the figure return from .peek() [#2487]
  + Bug Fixes
  * Improve TimeSeriesBase docstring [#2399]
  * Validate that pytest-doctestplus is installed [#2388]
  * Fix use of self.wcs in plot in mapbase [#2398]
  * Updated docstring with pointer to access EVE data for other levels [#2402]
  * Fix broken links and redirections in documentation [#2403]
  * Fixes Documentation changes due to NumPy 1.14 [#2404]
  * Added docstrings to functions in dowload.py [#2415]
  * Clean up database doc [#2414]
  * rhessi.py now uses sunpy.io instead of astropy.io [#2416]
  * Remove Gamma usage in Map [#2424]
  * Changed requirements to python-dateutil [#2426]
  * Clarify coordinate system definitions [#2429]
  * Improve Map Peek when using draw_grid [#2442]
  * Add HCC --> HGS test [#2443]
  * Testing the transformation linking SunPy and Astropy against published values [#2454]
  * Fixed title bug in sunpy.timeseries.rhessi [#2477]
  * Allow LineAnimator to accept a varying x-axis [#2491]
  * Indexing Bug Fix to LineAnimator [#2560]
  * Output sphinx warnings to stdout [#2553]
  * Docstring improvement for LineAnimator [#2514]
  * move the egg_info builds to circleci [#2512]
  * Added tests for TraceMap [#2504]
  * Fix HGS frame constructor and HPC ``calculate_distance`` with SkyCoord constructor. [#2463]
  * removed `wavelnth` keyword in meta desc of Maps to avoid using non standard FITS keyword like `nan` [#2456]
  * The documentation build now uses the Sphinx configuration from sphinx-astropy rather than from astropy-helpers.[#2494]
  * Migrate to hypothesis.strategies.datetimes [#2368]
  * Prevent a deprecation warning due to truth values of Quantity [#2358]
  * Print a warning when heliographic longitude is set to it's default value of 0 [#2480]
  * parse_time now parses numpy.datetime64 correctly. [#2572]
* Mon Feb 26 2018 toddrme2178@gmail.com
- Update to version 0.8.4
  + Bug Fixes
  * Improve detection of ``SkyCoord`` frame instantiation when distance is
    `1*u.one`. This fixes a plotting bug with ``WCSAxes`` in Astropy 3.0 [#2465]
  * removed `wavelnth` keyword in meta desc of Maps to avoid using non standard FITS keyword like `nan` [#2427]
  * Change the default units for HPC distance from `u.km` to `None`. [#2465]
- Update to version 0.8.3
  + Bug Fixes
  * `~sunpy.net.dataretriever.clients.XRSClient` now reports time ranges of files correctly. [#2364]
  * Make parse_time work with datetime64s and pandas series [#2370]
  * CompositeMap axes scaling now uses map spatial units [#2310]
  * Moved license file to root of repository and updated README file [#2326]
  * Fix docstring formatting for net.vso.attrs [#2309]]
  * Fix coloring of ticks under matplotlib 2.0 default style [#2320]
  * Always index arrays with tuples in `ImageAnimator` [#2320]
  * Added links to possible attrs for FIDO in guide [#2317] [#2289]
  * Updated GitHub Readme [#2281] [#2283]
  * Fix matplotlib / pandas 0.21 bug in examples [#2336]
  * Fixes the off limb enhancement example [#2329]
  * Changes to masking hot pixels and picking bright pixels examples [#2325] [#2319]
  * Travis CI fix for numpy-dev build [#2340]
  * Updated masking brightest pixel example [#2338]
  * Changed TRAVIS cronjobs [#2338]
  * Support array values for `obstime` for coordinates and transformations [#2342] [#2346]
  * Updated Gallery off limb enhance example [#2337]
  * Documentation fixes for VSO [#2354] [#2353]
  * All tests within the documentation have been fixed [#2343]
  * Change to using pytest-remotedata for our online tests [#2345]
  * Fixed upstream astropy/numpy documentation issues [#2359]
  * Documentation for Map improved [#2361]
  * Fix the output units of pixel_to_world [#2362]
  * Documentation for Database improved [#2355]
  * Added test for mapsave [#2365]
  * Documentation for Sun improved [#2369]
* Thu Jun 22 2017 alarrosa@suse.com
- Initial release of python-sunpy 0.7.8
